@@ -1,7 +1,7 @@
 """Command line interface."""
 
-import os
 import sys
+import threading
 from pathlib import Path
 from typing import List, Optional
 
@@ -10,12 +10,13 @@ import xdg
 from libcli import BaseCLI
 from loguru import logger
 
+import tf2mon.layouts
 from tf2mon.conlog import Conlog
 from tf2mon.logger import configure_logger
-from tf2mon.tf2monitor import TF2Monitor
+from tf2mon.monitor import Monitor
 
 
-class Tf2monCLI(BaseCLI):
+class CLI(BaseCLI):
     """Command line interface."""
 
     _cachedir = xdg.xdg_cache_home() / __package__
@@ -41,6 +42,7 @@ class Tf2monCLI(BaseCLI):
         "players": _cachedir / "steamplayers.db",
         "hackers-base": _cachedir / "playerlist.milenko-list.json",
         "hackers-local": _cachedir / "playerlist.tf2mon-list.json",
+        "webapi_key": "",
         # this player.
         "player_name": "Bad Dad",
     }
@@ -49,6 +51,14 @@ class Tf2monCLI(BaseCLI):
         "app-name",
     ]
 
+    def init_logging(self, verbose: int) -> None:
+        """Set logging levels based on `--verbose`."""
+
+        first_time = not self.init_logging_called
+        super().init_logging(verbose)
+        if first_time:
+            configure_logger()
+
     def init_parser(self) -> None:
         """Initialize argument parser."""
 
@@ -127,6 +137,14 @@ class Tf2monCLI(BaseCLI):
         )
         self.add_default_to_help(arg)
 
+        arg = self.parser.add_argument(
+            "--layout",
+            choices=[x.name for x in list(tf2mon.layouts.LAYOUT_ENUM)],
+            default=list(tf2mon.layouts.LAYOUT_ENUM)[0].name,
+            help="choose display layout",
+        )
+        self.add_default_to_help(arg)
+
         arg = self.parser.add_argument(
             "con_logfile",
             default=Path(self.config["con_logfile"]),
@@ -190,6 +208,13 @@ class Tf2monCLI(BaseCLI):
             help="read list of inject commands from `FILE`",
         )
 
+        arg = group.add_argument(
+            "--toggles",
+            action="store_true",
+            help="allow toggles when `--rewind`",
+        )
+        self.add_default_to_help(arg)
+
         group = self.parser.add_argument_group("Database options")
 
         arg = group.add_argument(
@@ -404,10 +429,8 @@ class Tf2monCLI(BaseCLI):
     def main(self) -> None:
         """Command line interface entry point (method)."""
 
-        configure_logger()
-
-        if "webapi_key" not in self.config:
-            self.parser.error("Missing config `webapi_key`")
+        # if "webapi_key" not in self.config:
+        #     self.parser.error("Missing config `webapi_key`")
 
         if self.options.con_logfile == self.config["con_logfile"]:
             # Not given on command line; prefix with effective parent.
@@ -424,7 +447,7 @@ class Tf2monCLI(BaseCLI):
             print(self.options.con_logfile)
             sys.exit(0)
 
-        monitor = TF2Monitor(self.options, self.config)
+        monitor = Monitor(self)
 
         if self.options.trunc_con_logfile:
             Conlog(monitor).trunc()
@@ -446,14 +469,14 @@ class Tf2monCLI(BaseCLI):
             ic(sp)  # noqa
             sys.exit(0)
 
-        if os.isatty(sys.stderr.fileno()):
-            cmd = " ".join([self.parser.prog] + sys.argv[1:] + ["2>x"])
-            logger.error(f"Please redirect `stderr`; try `{cmd}`")
-            sys.exit(0)
+        if self.options.layout:  # get enum from name
+            self.options.layout = tf2mon.layouts.LAYOUT_ENUM.__dict__[self.options.layout]
 
         monitor.run()
 
 
 def main(args: Optional[List[str]] = None) -> None:
     """Command line interface entry point (function)."""
-    return Tf2monCLI(args).main()
+
+    threading.current_thread().name = "MAIN"
+    return CLI(args).main()
